========
Examples
========

Code snippets
=============

Each function contains a few examples in the documentation.

Example files
=============

You can also check the `Examples`_ files on how to use some of the functions

.. _Examples: https://github.com/CenterForTheBuiltEnvironment/pythermalcomfort/tree/master/examples

Video tutorials
===============

If instead of reading you prefer watching, you can check the YouTube `tutorials`_ playlist

.. _tutorials: https://youtube.com/playlist?list=PLY91jl6VVD7zMaJjRVrVkaBtI56U7ztQC

.. raw:: html

    <div style="margin-bottom:2rem">
        <iframe width="100%" height="360" src="https://www.youtube.com/embed/OPz0GZxNsuw" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>
    </div>
